Sharma, Prashant; Sharma, Harish; Kumar, Sandeep; Bansal, Jagdish Chand
(2019):
A Review on Scale Factor Strategies in Differential Evolution Algorithm.
pp. 925-934. In:
Bansal, Jagdish Chand et al. (2019)
Soft Computing for Problem Solving.
Advances in Intelligent Systems and Computing, Vol. 817.
Springer, Singapore, 2019. (ISBN:978-981-13-1594-7)
Das, Swagatam; Konar, Amit; Chakraborty, Uday K. (2005):
Two Improved Differential Evolution Schemes for Faster Global Search.
pp. 991-998. In:
Proceedings of the 7th Annual Conference on
Genetic and Evolutionary Computation, Association for Computing Machinery,
New York. (doi:10.1145/1068009.1068177)