Learn R Programming

xegaDfGene (version 1.0.0.9)

xegaDfCrossGene: One point crossover of 2 genes.

Description

xegaDfCrossGene() randomly determines a cut point. It combines the parameters before the cut point of the first gene with the parameters after the cut point from the second gene (kid 1).

Usage

xegaDfCrossGene(gg1, gg2, lF)

Value

Real-coded gene.

Arguments

gg1

Real-coded gene.

gg2

Real-coded gene.

lF

Local configuration of the genetic algorithm.

See Also

Other Crossover (Returns 1 Kid): xegaDfUCrossGene(), xegaDfUPCrossGene()

Examples

Run this code
gene1<-xegaDfInitGene(lFxegaDfGene)
gene2<-xegaDfInitGene(lFxegaDfGene)
gene3<-xegaDfCrossGene(gene1, gene2, lFxegaDfGene)

Run the code above in your browser using DataLab