Learn R Programming

xegaDfGene (version 1.0.0.9)

xegaDfGeneMapFactory: Configure the gene map function of a genetic algorithm.

Description

xegaDfGeneMapFactory() implements the selection of one of the GeneMap functions in this package by specifying a text string. The selection fails ungracefully (produces a runtime error) if the label does not match. The functions are specified locally.

Current support:

  1. "Identity" returns GeneMapIdentity(). (Default)

Usage

xegaDfGeneMapFactory(method = "Identity")

Value

Gene map function for genes.

Arguments

method

String specifying the GeneMap function.

See Also

Other Configuration: lFxegaDfGene, xegaDfCrossoverFactory(), xegaDfMutationFactory(), xegaDfReplicationFactory(), xegaDfScaleFactorFactory()

Examples

Run this code
XGene<-xegaDfGeneMapFactory("Identity")
gene1<-xegaDfInitGene(lFxegaDfGene)
XGene(gene1, lFxegaDfGene$penv)

Run the code above in your browser using DataLab