xegaDfUCrossGene() swaps alleles of both genes
with a probability of 0.5. It generates a random
mask which is used to build the new gene.
Usage
xegaDfUCrossGene(gg1, gg2, lF)
Value
Real-coded gene.
Arguments
gg1
Real-coded gene.
gg2
Real-coded gene.
lF
Local configuration of the genetic algorithm.
References
Syswerda, Gilbert (1989):
Uniform Crossover in Genetic Algorithms.
In: Schaffer, J. David (Ed.)
Proceedings of the Third International Conference on Genetic Algorithms,
Morgan Kaufmann Publishers, Los Altos, California, pp. 2-9.
(ISBN:1-55860-066-3)
See Also
Other Crossover (Returns 1 Kid):
xegaDfCrossGene(),
xegaDfUPCrossGene()