xegaDfCrossGene() randomly determines a cut point.
It combines the parameters before the cut point of the first gene
with the parameters after the cut point from the second gene (kid 1).
Usage
xegaDfCrossGene(gg1, gg2, lF)
Value
Real-coded gene.
Arguments
gg1
Real-coded gene.
gg2
Real-coded gene.
lF
Local configuration of the genetic algorithm.
See Also
Other Crossover (Returns 1 Kid):
xegaDfUCrossGene(),
xegaDfUPCrossGene()